@@ -1,4 +1,5 @@
 import logging
+from contracts_lib_py.keeper import Keeper
 
 import pytest
 from common_utils_py.agreements.service_agreement import ServiceAgreement
@@ -8,8 +9,7 @@ from common_utils_py.did import DID
 from contracts_lib_py.exceptions import DIDNotFound
 from contracts_lib_py.web3_provider import Web3Provider
 
-from tests.resources.helper_functions import (get_algorithm_ddo, get_workflow_ddo,
-                                              log_event, get_metadata)
+from tests.resources.helper_functions import log_event
 
 
 def create_asset(publisher_instance, ddo_sample):
@@ -54,7 +54,7 @@ def test_resolve_did(publisher_instance, metadata):
     # metadata = Metadata.get_example()
     publisher = publisher_instance.main_account
     # happy path
-    original_ddo = publisher_instance.assets.create(metadata, publisher)
+    original_ddo = publisher_instance.assets.create(metadata, publisher, activity_id=publisher.address, attributes='test123')
     did = original_ddo.did
     ddo = publisher_instance.assets.resolve(did).as_dictionary()
     original = original_ddo.as_dictionary()
@@ -244,31 +244,26 @@ def test_assets_search(publisher_instance, metadata):
     publisher_instance.assets.retire(ddo.did)
 
 
-def test_assets_validate(publisher_instance, metadata):
-    assert publisher_instance.assets.validate(metadata)
-
-
-def test_assets_algorithm(publisher_instance):
+def test_assets_algorithm(publisher_instance, algorithm_ddo):
     # Allow publish an algorithm
     publisher = publisher_instance.main_account
-    metadata = get_algorithm_ddo()['service'][0]
+    metadata = algorithm_ddo['service'][0]
     ddo = publisher_instance.assets.create(metadata['attributes'], publisher)
     assert ddo
     publisher_instance.assets.retire(ddo.did)
 
 
-def test_assets_workflow(publisher_instance):
+def test_assets_workflow(publisher_instance, workflow_ddo):
     # Allow publish an workflow
     publisher = publisher_instance.main_account
-    metadata = get_workflow_ddo()['service'][0]
+    metadata = workflow_ddo['service'][0]
     ddo = publisher_instance.assets.create(metadata['attributes'], publisher)
     assert ddo
     publisher_instance.assets.retire(ddo.did)
 
 
-def test_assets_compute(publisher_instance):
+def test_assets_compute(publisher_instance, metadata):
     publisher = publisher_instance.main_account
-    metadata = get_metadata()
     ddo = publisher_instance.assets.create_compute(metadata, publisher)
     assert ddo
     publisher_instance.assets.retire(ddo.did)
@@ -289,30 +284,134 @@ def test_grant_permissions(publisher_instance, metadata, consumer_instance):
     publisher = publisher_instance.main_account
     consumer = consumer_instance.main_account
     ddo = publisher_instance.assets.create(metadata, publisher)
+
     assert not publisher_instance.assets.get_permissions(ddo.did, consumer.address)
     publisher_instance.assets.delegate_persmission(ddo.did, consumer.address, publisher)
     assert publisher_instance.assets.get_permissions(ddo.did, consumer.address)
     publisher_instance.assets.revoke_permissions(ddo.did, consumer.address, publisher)
     assert not publisher_instance.assets.get_permissions(ddo.did, consumer.address)
 
+    publisher_instance.assets.retire(ddo.did)
 
-def test_execute_workflow(publisher_instance, consumer_instance):
-    publisher = publisher_instance.main_account
-    consumer = consumer_instance.main_account
-    metadata = get_workflow_ddo()['service'][0]
-    workflow_ddo = publisher_instance.assets.create(metadata['attributes'], publisher)
+
+def test_execute_workflow(publisher_instance_no_init, consumer_instance_no_init, metadata, algorithm_ddo, workflow_ddo):
+    consumer = publisher_instance_no_init.main_account
+    publisher = consumer_instance_no_init.main_account
+
+    # publish compute
+    ddo_computing = publisher_instance_no_init.assets.create_compute(metadata, publisher)
+
+    # publish algorithm
+    metadata = algorithm_ddo['service'][0]
+    ddo_algorithm = consumer_instance_no_init.assets.create(metadata['attributes'], consumer)
+
+    metadata = workflow_ddo['service'][0]
+    metadata['attributes']['main']['workflow']['stages'][0]['input'][0]['id'] = ddo_computing.did
+    metadata['attributes']['main']['workflow']['stages'][0]['transformation']['id'] = ddo_algorithm.did
+    workflow_ddo = consumer_instance_no_init.assets.create(metadata['attributes'], publisher)
     assert workflow_ddo
-    metadata = get_metadata()
-    ddo_computing = publisher_instance.assets.create_compute(metadata, publisher)
-    assert ddo_computing
+
+    # order compute asset
     service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
     sa = ServiceAgreement.from_service_dict(service.as_dictionary())
-    agreement_id = consumer_instance.assets.order(ddo_computing.did, sa.index, consumer)
-    consumer_instance.assets.execute(agreement_id, ddo_computing.did, sa.index, consumer,
-                                     workflow_ddo.did)
-    publisher_instance.assets.retire(ddo_computing.did)
-    publisher_instance.assets.retire(workflow_ddo.did)
+    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer)
 
+    keeper = Keeper.get_instance()
+    event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
+        agreement_id, 60, None, (), wait=True
+    )
+    assert event is not None, "Reward condition is not found"
+
+    # execute workflow
+    execution_id = consumer_instance_no_init.assets.execute(agreement_id, ddo_computing.did, sa.index, consumer,
+        workflow_ddo.did)
+    assert execution_id
+
+    publisher_instance_no_init.assets.retire(ddo_computing.did)
+    publisher_instance_no_init.assets.retire(ddo_algorithm.did)
+    publisher_instance_no_init.assets.retire(workflow_ddo.did)
+
+
+def test_compute_status(publisher_instance_no_init, consumer_instance_no_init, metadata, algorithm_ddo, workflow_ddo):
+    consumer = publisher_instance_no_init.main_account
+    publisher = consumer_instance_no_init.main_account
+
+    # publish compute
+    ddo_computing = publisher_instance_no_init.assets.create_compute(metadata, publisher)
+
+    # publish algorithm
+    metadata = algorithm_ddo['service'][0]
+    ddo_algorithm = consumer_instance_no_init.assets.create(metadata['attributes'], consumer)
+
+    metadata = workflow_ddo['service'][0]
+    metadata['attributes']['main']['workflow']['stages'][0]['input'][0]['id'] = ddo_computing.did
+    metadata['attributes']['main']['workflow']['stages'][0]['transformation']['id'] = ddo_algorithm.did
+    workflow_ddo = consumer_instance_no_init.assets.create(metadata['attributes'], publisher)
+    assert workflow_ddo
+
+    # order compute asset
+    service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
+    sa = ServiceAgreement.from_service_dict(service.as_dictionary())
+    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer)
+
+    keeper = Keeper.get_instance()
+    event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
+        agreement_id, 60, None, (), wait=True
+    )
+    assert event is not None, "Reward condition is not found"
+
+    # execute workflow
+    execution_id = consumer_instance_no_init.assets.execute(agreement_id, ddo_computing.did, sa.index, consumer,
+        workflow_ddo.did)
+
+    # get status
+    status = consumer_instance_no_init.assets.compute_status(agreement_id, execution_id, consumer)
+    assert status
+
+    publisher_instance_no_init.assets.retire(ddo_computing.did)
+    publisher_instance_no_init.assets.retire(ddo_algorithm.did)
+    publisher_instance_no_init.assets.retire(workflow_ddo.did)
+
+
+def test_compute_logs(publisher_instance_no_init, consumer_instance_no_init, metadata, algorithm_ddo, workflow_ddo):
+    consumer = publisher_instance_no_init.main_account
+    publisher = consumer_instance_no_init.main_account
+
+    # publish compute
+    ddo_computing = publisher_instance_no_init.assets.create_compute(metadata, publisher)
+
+    # publish algorithm
+    metadata = algorithm_ddo['service'][0]
+    ddo_algorithm = consumer_instance_no_init.assets.create(metadata['attributes'], consumer)
+
+    metadata = workflow_ddo['service'][0]
+    metadata['attributes']['main']['workflow']['stages'][0]['input'][0]['id'] = ddo_computing.did
+    metadata['attributes']['main']['workflow']['stages'][0]['transformation']['id'] = ddo_algorithm.did
+    workflow_ddo = consumer_instance_no_init.assets.create(metadata['attributes'], publisher)
+    assert workflow_ddo
+
+    # order compute asset
+    service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
+    sa = ServiceAgreement.from_service_dict(service.as_dictionary())
+    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer)
+
+    keeper = Keeper.get_instance()
+    event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
+        agreement_id, 60, None, (), wait=True
+    )
+    assert event is not None, "Reward condition is not found"
+
+    # execute workflow
+    execution_id = consumer_instance_no_init.assets.execute(agreement_id, ddo_computing.did, sa.index, consumer,
+        workflow_ddo.did)
+
+    # get logs
+    logs = consumer_instance_no_init.assets.compute_logs(agreement_id, execution_id, consumer)
+    assert logs
+
+    publisher_instance_no_init.assets.retire(ddo_computing.did)
+    publisher_instance_no_init.assets.retire(ddo_algorithm.did)
+    publisher_instance_no_init.assets.retire(workflow_ddo.did)
 
 def test_agreement_direct(publisher_instance, consumer_instance, metadata):
     publisher_account = publisher_instance.main_account
